@@ -17,13 +17,13 @@ import pickle as pkl
 import os
 import json
 import pandas as pd
+import numpy as np
 from typing import Union, Dict, Any, List
 from dlk.utils.parser import BaseConfigParser, PostProcessorConfigParser
 from dlk.data.postprocessors import postprocessor_register, postprocessor_config_register, IPostProcessor, IPostProcessorConfig
 from dlk.utils.logger import Logger
 import torch
 from dlk.utils.vocab import Vocabulary
-import torchmetrics
 
 logger = Logger.get_logger()
 
@@ -53,7 +53,6 @@ class TxtClsPostProcessorConfig(IPostProcessorConfig):
         >>>         },
         >>>         "save_root_path": ".",  //save data root dir
         >>>         "top_k": 1, //the result return top k result
-        >>>         "focus": [], //always return the list label values which index in 'focus' list, if the focus[0] == 'pos', then the predict value always return the logits[vocab.get_index('pos')], and the label always be 'pos'
         >>>         "data_type": "single", //single or pair
         >>>         "save_path": {
         >>>             "valid": "valid",  // relative dir for valid stage
@@ -81,7 +80,6 @@ class TxtClsPostProcessorConfig(IPostProcessorConfig):
         self.label_ids = self.input_map['label_ids']
         self._index = self.input_map['_index']
         self.top_k = self.config['top_k']
-        self.focus = self.config['focus']
         if isinstance(self.config['meta'], str):
             meta = pkl.load(open(self.config['meta'], 'rb'))
         else:
@@ -105,7 +103,6 @@ class TxtClsPostProcessorConfig(IPostProcessorConfig):
             "origin_input_map",
             "save_root_path",
             "top_k",
-            "focus",
             "data_type",
             "save_path",
             "start_save_step",
@@ -120,7 +117,6 @@ class TxtClsPostProcessor(IPostProcessor):
         super(TxtClsPostProcessor, self).__init__()
         self.config = config
         self.label_vocab = self.config.label_vocab
-        self.acc_calc = torchmetrics.Accuracy()
 
     def do_predict(self, stage: str, list_batch_outputs: List[Dict], origin_data: pd.DataFrame, rt_config: Dict)->List:
         """Process the model predict to human readable format
@@ -129,7 +125,8 @@ class TxtClsPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -165,25 +162,20 @@ class TxtClsPostProcessor(IPostProcessor):
                     sentence_b = one_origin[self.config.sentence_b]
                     one_ins['sentence_b'] = sentence_b
                 uuid = one_origin[self.config.uuid]
-                if self.config.focus:
-                    label_values, label_indeies = [], []
-                    for label_name in self.config.focus:
-                        label_index = self.label_vocab.get_index(label_name)
-                        label_values.append(one_logits[label_index])
-                        label_indeies.append(label_index)
-                else:
-                    label_values, label_indeies = torch.topk(one_logits, self.config.top_k, dim=-1)
-                predict = []
-                for label_value, label_index in zip(label_values, label_indeies):
+                label_values, label_indeies = torch.topk(one_logits, self.config.top_k, dim=-1)
+                predict = {}
+                for i, (label_value, label_index) in enumerate(zip(label_values, label_indeies)):
                     label_name = self.label_vocab.get_word(label_index)
-                    predict.append([label_name, float(label_value)])
-                if label_id is None:
-                    ground_truth = ""
-                else:
-                    ground_truth = self.label_vocab.get_word(label_id)
+                    predict[i] = [label_name, float(label_value)]
+                ground_truth = []
+                if label_id is not None and label_id.shape:
+                    for one_label_id in label_id:
+                        ground_truth.append(self.label_vocab.get_word(one_label_id))
+                elif label_id:
+                    ground_truth.append(self.label_vocab.get_word(label_id))
                 one_ins['uuid'] = uuid
                 one_ins['labels'] = ground_truth
-                one_ins['predict_labels'] = predict
+                one_ins['predicts'] = predict
                 results.append(one_ins)
         return results
 
@@ -192,10 +184,12 @@ class TxtClsPostProcessor(IPostProcessor):
 
         Args:
             predicts: list of predicts
+                
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -207,12 +201,17 @@ class TxtClsPostProcessor(IPostProcessor):
             the named scores, acc
 
         """
-        for outputs in list_batch_outputs:
-            logits = outputs[self.config.logits]
-            label_ids = outputs[self.config.label_ids].squeeze(-1)
-            self.acc_calc.update(logits, label_ids)
+        right_num = 0
+        for one_ins in predicts:
+            labels = one_ins['labels']
+            assert len(labels) == 1, "We currently is not support multi label in txt_cls postprocess"
+            label = labels[0]
+            one_predicts = one_ins['predicts']
+            predict_label, predict_value = one_predicts[0] # the first predict
+            if label == predict_label:
+                right_num += 1
         real_name = self.loss_name_map(stage)
-        return {f'{real_name}_acc': self.acc_calc.compute()}
+        return {f'{real_name}_acc': right_num/len(predicts)}
 
     def do_save(self, predicts: List, stage: str, list_batch_outputs: List[Dict], origin_data: pd.DataFrame, rt_config: Dict, save_condition: bool=False):
         """save the predict when save_condition==True
@@ -222,7 +221,8 @@ class TxtClsPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -238,7 +238,7 @@ class TxtClsPostProcessor(IPostProcessor):
         if self.config.start_save_epoch == -1 or self.config.start_save_step == -1:
             self.config.start_save_step = rt_config.get('total_steps', 0) - 1
             self.config.start_save_epoch = rt_config.get('total_epochs', 0) - 1
-        if rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch:
+        if not save_condition and (rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch):
             save_condition = True
         if save_condition:
             save_path = os.path.join(self.config.save_root_path, self.config.save_path.get(stage, ''))
@@ -249,4 +249,5 @@ class TxtClsPostProcessor(IPostProcessor):
             else:
                 save_file = os.path.join(save_path, 'predict.json')
             logger.info(f"Save the {stage} predict data at {save_file}")
-            json.dump(predicts, open(save_file, 'w'), indent=4)
+            json.dump(predicts, open(save_file, 'w'), indent=4, ensure_ascii=False)
+
